/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { AfterViewInit, EventEmitter, OnDestroy, TemplateRef } from '@angular/core';
import { MatPaginator } from '@angular/material/paginator';
import { MatTableDataSource } from '@angular/material/table';
import { JsonModel } from '@ngx-material-dashboard/base-json';
import { Subscription } from 'rxjs';
import { ButtonClick } from '../../../toolbar/interfaces/button-click.interface';
import { Button } from '../../interfaces/button.interface';
import { RemoteDataSource } from '../../services/remote-data-source.service';
import { CollectionComponent } from '../collection/collection.component';
import * as i0 from "@angular/core";
/**
 * The `PagedCollection` is a wrapper component for the `Collection` which adds
 * paging capabilities. This component expects a `Collection` to be defined as
 * a child in the template. Any paginator used should be of type `MatPaginator`.
 *
 * @overviewDetails
 *
 * Like the `Collection`, this component does not provide a template, and
 * the intention is for you to use things like the `PagedGrid`, `PagedList`,
 * or `PagedTable` instead of using this component directly. The only time you
 * might utilize this component directly is if you use it to create your own
 * paged collection type component (if the existing `PagedGrid`, `PagedList`,
 * or `PagedTable` do not provide the capabilities you need). If you do define
 * your own paged collection, you must define a template for it. You can find
 * more details in the documentation for the
 * [PagedGrid](/widgets/grid/overview#paged-grid-component),
 * [PagedList](/widgets/list/overview#paged-list-component),
 * and [PagedTable](/widgets/table/overview#paged-table-component) at the included links.
 *
 * #### Features
 *
 * The `PagedCollection` provides paging capabilities for collections.
 *
 * ##### Paginator
 *
 * The `paginator$` is a ViewChild property defined for the `PagedCollection`,
 * and is treated as an internal value specifically for this component. The
 * `paginator` getter is defined to be a more `public` facing property, and used
 * when initializing the paginator for the dataSource. If you create your own
 * paged collection by extending this component, all you need to do for the
 * paginator to work is add a `MatPaginator` to the template. If you use
 * something other than a `MatPaginator` or a ViewChild (i.e. ContentChild),
 * then you can override the `paginator` getter to return the type of paginator
 * you use in your component. *NOTE: whatever paginator you do use must extend
 * `MatPaginator` in order to work with the dataSource.
 */
export declare class PagedCollectionComponent<T extends JsonModel> implements AfterViewInit, OnDestroy {
    /**
     * A reference to the model template for each element in the collection.
     * This is mainly used for any collection other than a table.
     */
    template: TemplateRef<any>;
    /** The buttons to render with each item in collection. */
    collectionButtons: Button[];
    /** The dataSource for the collection. */
    set dataSource(val: T[] | MatTableDataSource<T> | RemoteDataSource<T>);
    /** List of fields included in each element of collection that can be sorted on. */
    fields: string[];
    /**
     * The max number of pages to display in the paginator. Defaults to 10
     * (does not include 'First', 'Prev', 'Next', 'Last').
     */
    maxPages: number;
    /** Boolean value to indicate whether multiple rows can be selected. */
    multiple: boolean;
    /** Number of items to display on a page. Defaults to 25. */
    pageSize: number;
    /** The event to emit when button is clicked in collection. */
    buttonClick: EventEmitter<ButtonClick>;
    /** A reference to the paginator in the template. */
    paginator$?: MatPaginator;
    /** A reference to the collection in the template. */
    collection$: CollectionComponent<T>;
    dataSource$: T[] | MatTableDataSource<T> | RemoteDataSource<T>;
    /** The total number of elements in the collection. */
    length: number;
    /** The subscriptions for the component. */
    sub: Subscription;
    get dataSource(): T[] | MatTableDataSource<T> | RemoteDataSource<T>;
    /**
     * Returns the paginator for the component if it exists.
     */
    get paginator(): MatPaginator | null;
    constructor();
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * Initializes subscription for when user changes page or page size. Works
     * for both local and remote data.
     */
    initPaginator(): void;
    /**
     * Handler for when the user clicks a button associated with an item in the
     * collection.
     *
     * @param buttonClick The value emitted from the collection.
     */
    onButtonClick(buttonClick: ButtonClick): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PagedCollectionComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PagedCollectionComponent<any>, "ng-component", never, { "collectionButtons": "collectionButtons"; "dataSource": "dataSource"; "fields": "fields"; "maxPages": "maxPages"; "multiple": "multiple"; "pageSize": "pageSize"; }, { "buttonClick": "buttonClick"; }, ["template"], never>;
}
