/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { SelectionModel } from '@angular/cdk/collections';
import { EventEmitter } from '@angular/core';
import { MatCheckboxChange } from '@angular/material/checkbox';
import { MatPaginator } from '@angular/material/paginator';
import { JsonModel } from '@ngx-material-dashboard/base-json';
import { Subscription } from 'rxjs';
import { ButtonClick } from '../../interfaces/button-click.interface';
import { ToolbarButton } from '../../interfaces/toolbar-button.interface';
import { SorterComponent } from '../sorter/sorter.component';
import * as i0 from "@angular/core";
/**
 * A toolbar that renders `mat-icon-button`s and a paginator with optional
 * select checkbox and sorting capability. It is designed to be rendered above
 * paged collections since the paginator is automatically included on the right
 * side of the toolbar. Unlike the `RaisedButtonToolbar you cannot control the
 * button alignment; buttons are aligned left, after the optional select
 * checkbox, and the paginator is aligned to the right side of the page, after
 * the optional `Sorter`.
 *
 * #### Features
 *
 * You may optional exclude a select checkbox and `Sorter`. These default to
 * automatically be included. Simply set the corresponding `display` input
 * value to `false` if you want to exclude either feature.
 *
 * ##### Optional Select Checkbox
 *
 * The optional select checkbox is meant to act as a master toggle for
 * collections, similar to the master toggle rendered in the header row above
 * a table with select option. See the material
 * [docs](https://material.angular.io/components/table/examples#table-selection)
 * for what I'm talking about. If included it is the first thing rendered in
 * the toolbar so it can line up with collection content rendered as a list. If
 * you use the PagedListWithRaisedButtonToolbar, you should see the checkbox
 * line up with the checkbox rendered for each row in the list (just like it is
 * in the table with select). This was made optional so this toolbar can be used
 * above the `PagedTable` that already includes the master toggle select in the
 * header row (there is no reason to include multiple master toggles).
 *
 * To handle when the user (de)selects the checkbox you can use the
 * `masterToggle` output event emitter in the parent component.
 *
 * ##### Sorter
 *
 * The optional `Sorter` is rendered before the `MatPaginator` and is meant
 * to sort contents of the collection. Like the masterToggle, this is optional
 * so this toolbar can be used above the `PagedTable`, which already includes
 * sorting in the header row.
 */
export declare class IconButtonsWithPaginatorComponent<T extends JsonModel> {
    /** The management buttons to display in the toolbar. */
    buttons: ToolbarButton[];
    /** Boolean to indicate whether to render the select all checkbox. */
    displaySelectAll: boolean;
    /** Boolean to indicate whether to render the sort drop down. */
    displaySort: boolean;
    /** The fields to render in the sort drop down. */
    fields: string[];
    /** Boolean to indicate whether all items are selected. */
    isAllSelected: boolean;
    /** The total number of items in the collection. */
    length: number;
    /** Boolean to indicate whether multiple items can be selected. */
    multiple: boolean;
    /** The number of items to render in the page. */
    pageSize: number;
    /** The model to track items selected in the table. */
    selection: SelectionModel<T>;
    /** Event emitted when user clicks button in toolbar. */
    buttonClick: EventEmitter<ButtonClick>;
    /** Event emitted when user clicks the select all checkbox. */
    masterToggle: EventEmitter<boolean>;
    /** A reference to the paginator in the component. */
    paginator: MatPaginator;
    /** A reference to the sorter in the component. */
    sort: SorterComponent;
    /** The subscriptions for the component. */
    sub: Subscription;
    constructor();
    /**
     * Emits a buttonClick event to the parent.
     *
     * @param buttonClick The action from the button that was clicked by the user.
     */
    emitButtonClick(buttonClick: ButtonClick): void;
    /**
     * Emits a masterToggle event to the parent with the latest value for the
     * master toggle checkbox.
     *
     * @param check The checkbox change event.
     */
    emitMasterToggle(check: MatCheckboxChange): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IconButtonsWithPaginatorComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IconButtonsWithPaginatorComponent<any>, "ngx-mat-icon-buttons-with-paginator", never, { "buttons": "buttons"; "displaySelectAll": "displaySelectAll"; "displaySort": "displaySort"; "fields": "fields"; "isAllSelected": "isAllSelected"; "length": "length"; "multiple": "multiple"; "pageSize": "pageSize"; "selection": "selection"; }, { "buttonClick": "buttonClick"; "masterToggle": "masterToggle"; }, never, never>;
}
